==> seedsui-react-5.7.93.tgz: package/lib/Location/Main/Error/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["errMsg"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useRef } from 'react';

// 测试使用
// import { Layout, Notice } from 'seedsui-react'
// 内库使用
import Layout from "./../../../Layout";
import Notice from "./../../../Notice";

// 地图位置选择
import { jsx as _jsx } from "react/jsx-runtime";
var Error = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var errMsg = _ref.errMsg,
    props = _objectWithoutProperties(_ref, _excluded);
  // 根节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2;
    return {
      rootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.getRootDOM
    };
  });
  return /*#__PURE__*/_jsx(Layout, _objectSpread(_objectSpread({
    ref: rootRef,
    className: "position-relative"
  }, props), {}, {
    children: /*#__PURE__*/_jsx(Notice, {
      caption: errMsg
    })
  }));
});
export default Error;

==> seedsui-react-5.8.44.tgz: package/lib/Location/Main/Error/index.js <==
var _excluded = ["errMsg"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useRef } from 'react';

// 测试使用
// import { Layout, Notice } from 'seedsui-react'
// 内库使用
import Layout from "./../../../Layout";
import Notice from "./../../../Notice";

// 地图位置选择
var Error = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var errMsg = _ref.errMsg,
    props = _objectWithoutProperties(_ref, _excluded);
  // 根节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2;
    return {
      rootDOM: rootRef === null || rootRef === void 0 || (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      getRootDOM: rootRef === null || rootRef === void 0 || (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.getRootDOM
    };
  });
  return /*#__PURE__*/React.createElement(Layout, _extends({
    ref: rootRef,
    className: "position-relative"
  }, props), /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));
});
export default Error;
